aboutsummaryrefslogtreecommitdiffstats
path: root/src/plugins
diff options
context:
space:
mode:
authorEike Ziller <eike.ziller@qt.io>2024-04-17 12:48:28 +0200
committerEike Ziller <eike.ziller@qt.io>2024-04-17 13:29:02 +0200
commit0fe73503688c6c4c256ffa39f1a30c329a5ca2e7 (patch)
treef35e6772a7742155ec62c084dd607a3027216795 /src/plugins
parent1f162377369d968cd7740d751bc41047591dbe0d (diff)
parentd4d8ea98b75545f99477d2b6a4c6aaaa1b354891 (diff)
Merge remote-tracking branch 'origin/13.0'
Diffstat (limited to 'src/plugins')
-rw-r--r--src/plugins/clangcodemodel/clangactivationsequencecontextprocessor.cpp2
-rw-r--r--src/plugins/cmakeprojectmanager/cmakebuildsystem.cpp84
-rw-r--r--src/plugins/cmakeprojectmanager/fileapidataextractor.cpp9
-rw-r--r--src/plugins/cmakeprojectmanager/projecttreehelper.cpp14
-rw-r--r--src/plugins/cmakeprojectmanager/projecttreehelper.h6
-rw-r--r--src/plugins/fakevim/fakevimplugin.cpp2
-rw-r--r--src/plugins/ios/iosrunner.cpp19
-rw-r--r--src/plugins/projectexplorer/appoutputpane.cpp16
-rw-r--r--src/plugins/projectexplorer/buildconfiguration.cpp10
-rw-r--r--src/plugins/projectexplorer/buildpropertiessettings.cpp5
-rw-r--r--src/plugins/projectexplorer/projectexplorerconstants.h2
-rw-r--r--src/plugins/texteditor/TextEditor.json.in15
12 files changed, 122 insertions, 62 deletions
diff --git a/src/plugins/clangcodemodel/clangactivationsequencecontextprocessor.cpp b/src/plugins/clangcodemodel/clangactivationsequencecontextprocessor.cpp
index 99c40c99b61..71419032249 100644
--- a/src/plugins/clangcodemodel/clangactivationsequencecontextprocessor.cpp
+++ b/src/plugins/clangcodemodel/clangactivationsequencecontextprocessor.cpp
@@ -132,7 +132,7 @@ void ActivationSequenceContextProcessor::processComment()
void ActivationSequenceContextProcessor::processInclude()
{
- if (m_token.isLiteral() && !isCompletionKindStringLiteralOrSlash())
+ if (m_token.isStringLiteral() && !isCompletionKindStringLiteralOrSlash())
m_completionKind = CPlusPlus::T_EOF_SYMBOL;
}
diff --git a/src/plugins/cmakeprojectmanager/fileapidataextractor.cpp b/src/plugins/cmakeprojectmanager/fileapidataextractor.cpp
index a3795369f76..c2a3e5804ab 100644
--- a/src/plugins/cmakeprojectmanager/fileapidataextractor.cpp
+++ b/src/plugins/cmakeprojectmanager/fileapidataextractor.cpp
@@ -633,7 +633,7 @@ static FolderNode *createSourceGroupNode(const QString &sourceGroupName,
FolderNode *existingNode = currentNode->findChildFolderNode(
[&p](const FolderNode *fn) { return fn->displayName() == p; });
if (!existingNode) {
- auto node = createCMakeVFolder(sourceDirectory, Node::DefaultFolderPriority + 5, p, true);
+ auto node = createCMakeVFolder(sourceDirectory, Node::DefaultFolderPriority + 5, p);
node->setListInProject(false);
node->setIcon([] { return Icon::fromTheme("edit-copy"); });
@@ -654,7 +654,6 @@ static void addCompileGroups(ProjectNode *targetRoot,
const FilePath &buildDirectory,
const TargetDetails &td)
{
- const bool showSourceFolders = settings().showSourceSubFolders();
const bool inSourceBuild = (sourceDirectory == buildDirectory);
QSet<FilePath> alreadyListed;
@@ -685,6 +684,9 @@ static void addCompileGroups(ProjectNode *targetRoot,
if (isPchFile(buildDirectory, sourcePath) || isUnityFile(buildDirectory, sourcePath))
node->setIsGenerated(true);
+ const bool showSourceFolders = settings().showSourceSubFolders()
+ && sourcesOrHeadersFolder(td.sourceGroups[si.sourceGroup]);
+
// Where does the file node need to go?
if (showSourceFolders && sourcePath.isChildOf(buildDirectory) && !inSourceBuild) {
buildFileNodes.emplace_back(std::move(node));
@@ -696,6 +698,9 @@ static void addCompileGroups(ProjectNode *targetRoot,
}
for (size_t i = 0; i < sourceGroupFileNodes.size(); ++i) {
+ const bool showSourceFolders = settings().showSourceSubFolders()
+ && sourcesOrHeadersFolder(td.sourceGroups[i]);
+
std::vector<std::unique_ptr<FileNode>> &current = sourceGroupFileNodes[i];
FolderNode *insertNode = td.sourceGroups[i] == "TREE"
? targetRoot
diff --git a/src/plugins/cmakeprojectmanager/projecttreehelper.cpp b/src/plugins/cmakeprojectmanager/projecttreehelper.cpp
index e17505095a6..d23f6a4f972 100644
--- a/src/plugins/cmakeprojectmanager/projecttreehelper.cpp
+++ b/src/plugins/cmakeprojectmanager/projecttreehelper.cpp
@@ -18,15 +18,19 @@ using namespace ProjectExplorer;
namespace CMakeProjectManager::Internal {
+bool sourcesOrHeadersFolder(const QString &displayName)
+{
+ return displayName == "Source Files" || displayName == "Header Files";
+}
+
std::unique_ptr<FolderNode> createCMakeVFolder(const Utils::FilePath &basePath,
int priority,
- const QString &displayName,
- bool sourcesOrHeaders)
+ const QString &displayName)
{
auto newFolder = std::make_unique<VirtualFolderNode>(basePath);
newFolder->setPriority(priority);
newFolder->setDisplayName(displayName);
- newFolder->setIsSourcesOrHeaders(sourcesOrHeaders);
+ newFolder->setIsSourcesOrHeaders(sourcesOrHeadersFolder(displayName));
return newFolder;
}
@@ -35,14 +39,13 @@ void addCMakeVFolder(FolderNode *base,
int priority,
const QString &displayName,
std::vector<std::unique_ptr<FileNode>> &&files,
- bool sourcesOrHeaders,
bool listInProject)
{
if (files.size() == 0)
return;
FolderNode *folder = base;
if (!displayName.isEmpty()) {
- auto newFolder = createCMakeVFolder(basePath, priority, displayName, sourcesOrHeaders);
+ auto newFolder = createCMakeVFolder(basePath, priority, displayName);
folder = newFolder.get();
base->addNode(std::move(newFolder));
}
@@ -90,7 +93,6 @@ void addCMakeInputs(FolderNode *root,
10,
Tr::tr("<Other Locations>"),
removeKnownNodes(knownFiles, std::move(rootInputs)),
- /*sourcesOrHeaders=*/false,
/*listInProject=*/false);
root->addNode(std::move(cmakeVFolder));
diff --git a/src/plugins/cmakeprojectmanager/projecttreehelper.h b/src/plugins/cmakeprojectmanager/projecttreehelper.h
index bcd5500db97..258e0a63231 100644
--- a/src/plugins/cmakeprojectmanager/projecttreehelper.h
+++ b/src/plugins/cmakeprojectmanager/projecttreehelper.h
@@ -11,17 +11,17 @@
namespace CMakeProjectManager::Internal {
+bool sourcesOrHeadersFolder(const QString &displayName);
+
std::unique_ptr<ProjectExplorer::FolderNode> createCMakeVFolder(const Utils::FilePath &basePath,
int priority,
- const QString &displayName,
- bool sourcesOrHeaders);
+ const QString &displayName);
void addCMakeVFolder(ProjectExplorer::FolderNode *base,
const Utils::FilePath &basePath,
int priority,
const QString &displayName,
std::vector<std::unique_ptr<ProjectExplorer::FileNode>> &&files,
- bool sourcesOrHeaders = false,
bool listInProject = true);
std::vector<std::unique_ptr<ProjectExplorer::FileNode>> &&removeKnownNodes(
diff --git a/src/plugins/fakevim/fakevimplugin.cpp b/src/plugins/fakevim/fakevimplugin.cpp
index 7a7554da9ea..a84598aec00 100644
--- a/src/plugins/fakevim/fakevimplugin.cpp
+++ b/src/plugins/fakevim/fakevimplugin.cpp
@@ -999,6 +999,7 @@ bool FakeVimUserCommandsModel::setData(const QModelIndex &index,
return true;
}
+#ifdef WITH_TESTS
static void setupTest(QString *title, FakeVimHandler **handler, QWidget **edit)
{
*title = QString::fromLatin1("test.cpp");
@@ -1040,7 +1041,6 @@ static void setupTest(QString *title, FakeVimHandler **handler, QWidget **edit)
(*handler)->handleCommand("set iskeyword=@,48-57,_,192-255,a-z,A-Z");
}
-#ifdef WITH_TESTS
QObject *createFakeVimTester( void (*setupTest)(QString *, FakeVimHandler **, QWidget **) ); // in fakevim_test.cpp
#endif
diff --git a/src/plugins/ios/iosrunner.cpp b/src/plugins/ios/iosrunner.cpp
index ff3d10f4915..e5b03e5229e 100644
--- a/src/plugins/ios/iosrunner.cpp
+++ b/src/plugins/ios/iosrunner.cpp
@@ -60,18 +60,29 @@ using namespace Tasking;
namespace Ios::Internal {
+static QString identifierForRunControl(RunControl *runControl)
+{
+ const IosDeviceTypeAspect::Data *data = runControl->aspectData<IosDeviceTypeAspect>();
+ return data ? data->deviceType.identifier : QString();
+}
+
static void stopRunningRunControl(RunControl *runControl)
{
static QMap<Id, QPointer<RunControl>> activeRunControls;
+ // clean up deleted
+ Utils::erase(activeRunControls, [](const QPointer<RunControl> &rc) { return !rc; });
+
Target *target = runControl->target();
- Id devId = DeviceKitAspect::deviceId(target->kit());
+ const Id devId = DeviceKitAspect::deviceId(target->kit());
+ const QString identifier = identifierForRunControl(runControl);
// The device can only run an application at a time, if an app is running stop it.
- if (activeRunControls.contains(devId)) {
- if (QPointer<RunControl> activeRunControl = activeRunControls[devId])
+ if (QPointer<RunControl> activeRunControl = activeRunControls[devId]) {
+ if (identifierForRunControl(activeRunControl) == identifier) {
activeRunControl->initiateStop();
- activeRunControls.remove(devId);
+ activeRunControls.remove(devId);
+ }
}
if (devId.isValid())
diff --git a/src/plugins/projectexplorer/appoutputpane.cpp b/src/plugins/projectexplorer/appoutputpane.cpp
index 742e6df5e4f..3d489460247 100644
--- a/src/plugins/projectexplorer/appoutputpane.cpp
+++ b/src/plugins/projectexplorer/appoutputpane.cpp
@@ -391,14 +391,14 @@ void AppOutputPane::createNewOutputWindow(RunControl *rc)
const CommandLine thisCommand = rc->commandLine();
const FilePath thisWorkingDirectory = rc->workingDirectory();
const Environment thisEnvironment = rc->environment();
- const auto tab = std::find_if(m_runControlTabs.begin(), m_runControlTabs.end(),
- [&](const RunControlTab &tab) {
- if (!tab.runControl || tab.runControl->isRunning() || tab.runControl->isStarting())
- return false;
- return thisCommand == tab.runControl->commandLine()
- && thisWorkingDirectory == tab.runControl->workingDirectory()
- && thisEnvironment == tab.runControl->environment();
- });
+ const auto tab = std::find_if(
+ m_runControlTabs.begin(), m_runControlTabs.end(), [&](const RunControlTab &tab) {
+ if (!tab.runControl || !tab.runControl->isStopped())
+ return false;
+ return thisCommand == tab.runControl->commandLine()
+ && thisWorkingDirectory == tab.runControl->workingDirectory()
+ && thisEnvironment == tab.runControl->environment();
+ });
if (tab != m_runControlTabs.end()) {
// Reuse this tab
if (tab->runControl)
diff --git a/src/plugins/projectexplorer/buildconfiguration.cpp b/src/plugins/projectexplorer/buildconfiguration.cpp
index d8b19767303..dd1e077af49 100644
--- a/src/plugins/projectexplorer/buildconfiguration.cpp
+++ b/src/plugins/projectexplorer/buildconfiguration.cpp
@@ -617,7 +617,15 @@ FilePath BuildConfiguration::buildDirectoryFromTemplate(const FilePath &projectD
[buildType] { return buildTypeName(buildType); });
exp.registerSubProvider([kit] { return kit->macroExpander(); });
- FilePath buildDir = FilePath::fromUserInput(buildPropertiesSettings().buildDirectoryTemplate());
+ auto project = ProjectManager::projectWithProjectFilePath(mainFilePath);
+ auto environment = Environment::systemEnvironment();
+ // This adds the environment variables from the <project>.shared file
+ if (project)
+ environment.modify(project->additionalEnvironment());
+
+ FilePath buildDir = FilePath::fromUserInput(environment.value_or(
+ Constants::QTC_DEFAULT_BUILD_DIRECTORY_TEMPLATE,
+ buildPropertiesSettings().buildDirectoryTemplate()));
qCDebug(bcLog) << "build dir template:" << buildDir.toUserOutput();
buildDir = exp.expand(buildDir);
qCDebug(bcLog) << "expanded build:" << buildDir.toUserOutput();
diff --git a/src/plugins/projectexplorer/buildpropertiessettings.cpp b/src/plugins/projectexplorer/buildpropertiessettings.cpp
index c9cde2624d8..5b60e6c9c13 100644
--- a/src/plugins/projectexplorer/buildpropertiessettings.cpp
+++ b/src/plugins/projectexplorer/buildpropertiessettings.cpp
@@ -8,6 +8,7 @@
#include <coreplugin/dialogs/ioptionspage.h>
+#include <utils/environment.h>
#include <utils/layoutbuilder.h>
using namespace Utils;
@@ -16,7 +17,9 @@ namespace ProjectExplorer {
static QString defaultBuildDirectoryTemplate()
{
- return "./build/%{Asciify:%{Kit:FileSystemName}-%{BuildConfig:Name}}";
+ return qtcEnvironmentVariable(
+ Constants::QTC_DEFAULT_BUILD_DIRECTORY_TEMPLATE,
+ "./build/%{Asciify:%{Kit:FileSystemName}-%{BuildConfig:Name}}");
}
BuildPropertiesSettings &buildPropertiesSettings()
diff --git a/src/plugins/projectexplorer/projectexplorerconstants.h b/src/plugins/projectexplorer/projectexplorerconstants.h
index 80ffefcc51f..ca0fe5c9e09 100644
--- a/src/plugins/projectexplorer/projectexplorerconstants.h
+++ b/src/plugins/projectexplorer/projectexplorerconstants.h
@@ -145,6 +145,8 @@ const char CUSTOM_TOOLCHAIN_TYPEID[] = "ProjectExplorer.ToolChain.Custom";
const char DEFAULT_WORKING_DIR[] = "%{buildDir}";
const char DEFAULT_WORKING_DIR_ALTERNATE[] = "%{sourceDir}";
+const char QTC_DEFAULT_BUILD_DIRECTORY_TEMPLATE[] = "QTC_DEFAULT_BUILD_DIRECTORY_TEMPLATE";
+
// Desktop Device related ids:
const char DESKTOP_DEVICE_ID[] = "Desktop Device";
const char DESKTOP_DEVICE_TYPE[] = "Desktop";
diff --git a/src/plugins/texteditor/TextEditor.json.in b/src/plugins/texteditor/TextEditor.json.in
index 447d9c91c67..f2b6fbbcf58 100644
--- a/src/plugins/texteditor/TextEditor.json.in
+++ b/src/plugins/texteditor/TextEditor.json.in
@@ -24,6 +24,21 @@
" <sub-class-of type='text/plain'/>",
" <glob pattern='*.dts' weight='80'/>",
" </mime-type>",
+ " <mime-type type='text/x-yacc'>",
+ " <comment>Yacc/Bison source files</comment>",
+ " <sub-class-of type='text/plain'/>",
+ " <glob pattern='*.y'/>",
+ " <glob pattern='*.yy'/>",
+ " <glob pattern='*.ypp'/>",
+ " <glob pattern='*.y++'/>",
+ " </mime-type>",
+ " <mime-type type='text/x-lex'>",
+ " <comment>Lex/Flex source files</comment>",
+ " <sub-class-of type='text/plain'/>",
+ " <glob pattern='*.l'/>",
+ " <glob pattern='*.lex'/>",
+ " <glob pattern='*.flex'/>",
+ " </mime-type>",
"</mime-info>"
]
}
diff --git a/src/plugins/cmakeprojectmanager/cmakebuildsystem.cpp b/src/plugins/cmakeprojectmanager/cmakebuildsystem.cpp
index 0ba54b60a81..25d51488f8b 100644
--- a/src/plugins/cmakeprojectmanager/cmakebuildsystem.cpp
+++ b/src/plugins/cmakeprojectmanager/cmakebuildsystem.cpp
@@ -749,14 +749,17 @@ CMakeBuildSystem::projectFileArgumentPosition(const QString &targetName, const Q
&& func.Arguments().size() > 1 && func.Arguments().front().Value == target_name;
});
- for (const auto &func : {function, targetSourcesFunc, addQmlModuleFunc}) {
+ auto setSourceFilePropFunc = findFunction(*cmakeListFile, [](const auto &func) {
+ return func.LowerCaseName() == "set_source_files_properties";
+ });
+
+ for (const auto &func : {function, targetSourcesFunc, addQmlModuleFunc, setSourceFilePropFunc}) {
if (!func.has_value())
continue;
- auto filePathArgument = Utils::findOrDefault(func->Arguments(),
- [file_name = fileName.toStdString()](
- const auto &arg) {
- return arg.Value == file_name;
- });
+ auto filePathArgument = Utils::findOrDefault(
+ func->Arguments(), [file_name = fileName.toStdString()](const auto &arg) {
+ return arg.Value == file_name;
+ });
if (!filePathArgument.Value.empty()) {
return ProjectFileArgumentPosition{filePathArgument, targetCMakeFile, fileName};
@@ -925,48 +928,59 @@ bool CMakeBuildSystem::renameFile(Node *context,
{
if (auto n = dynamic_cast<CMakeTargetNode *>(context)) {
const FilePath projDir = n->filePath().canonicalPath();
- const QString newRelPathName
- = newFilePath.canonicalPath().relativePathFrom(projDir).cleanPath().toString();
+ const FilePath newRelPath = newFilePath.canonicalPath().relativePathFrom(projDir).cleanPath();
+ const QString newRelPathName = newRelPath.toString();
+
+ // FilePath needs the file to exist on disk, the old file has already been renamed
+ const QString oldRelPathName
+ = newRelPath.parentDir().pathAppended(oldFilePath.fileName()).cleanPath().toString();
const QString targetName = n->buildKey();
const QString key
= QStringList{projDir.path(), targetName, oldFilePath.path(), newFilePath.path()}.join(
";");
- auto fileToRename = m_filesToBeRenamed.take(key);
- if (!fileToRename.cmakeFile.exists()) {
+ std::optional<CMakeBuildSystem::ProjectFileArgumentPosition> fileToRename
+ = m_filesToBeRenamed.take(key);
+ if (!fileToRename->cmakeFile.exists()) {
qCCritical(cmakeBuildSystemLog).noquote()
- << "File" << fileToRename.cmakeFile.path() << "does not exist.";
+ << "File" << fileToRename->cmakeFile.path() << "does not exist.";
return false;
}
- BaseTextEditor *editor = qobject_cast<BaseTextEditor *>(
- Core::EditorManager::openEditorAt({fileToRename.cmakeFile,
- static_cast<int>(fileToRename.argumentPosition.Line),
- static_cast<int>(fileToRename.argumentPosition.Column
- - 1)},
- Constants::CMAKE_EDITOR_ID,
- Core::EditorManager::DoNotMakeVisible));
- if (!editor) {
- qCCritical(cmakeBuildSystemLog).noquote()
- << "BaseTextEditor cannot be obtained for" << fileToRename.cmakeFile.path()
- << fileToRename.argumentPosition.Line << int(fileToRename.argumentPosition.Column);
- return false;
- }
+ do {
+ BaseTextEditor *editor = qobject_cast<BaseTextEditor *>(
+ Core::EditorManager::openEditorAt(
+ {fileToRename->cmakeFile,
+ static_cast<int>(fileToRename->argumentPosition.Line),
+ static_cast<int>(fileToRename->argumentPosition.Column - 1)},
+ Constants::CMAKE_EDITOR_ID,
+ Core::EditorManager::DoNotMakeVisible));
+ if (!editor) {
+ qCCritical(cmakeBuildSystemLog).noquote()
+ << "BaseTextEditor cannot be obtained for" << fileToRename->cmakeFile.path()
+ << fileToRename->argumentPosition.Line
+ << int(fileToRename->argumentPosition.Column);
+ return false;
+ }
- // If quotes were used for the source file, skip the starting quote
- if (fileToRename.argumentPosition.Delim == cmListFileArgument::Quoted)
- editor->setCursorPosition(editor->position() + 1);
+ // If quotes were used for the source file, skip the starting quote
+ if (fileToRename->argumentPosition.Delim == cmListFileArgument::Quoted)
+ editor->setCursorPosition(editor->position() + 1);
- if (!fileToRename.fromGlobbing)
- editor->replace(fileToRename.relativeFileName.length(), newRelPathName);
+ if (!fileToRename->fromGlobbing)
+ editor->replace(fileToRename->relativeFileName.length(), newRelPathName);
- editor->editorWidget()->autoIndent();
- if (!Core::DocumentManager::saveDocument(editor->document())) {
- qCCritical(cmakeBuildSystemLog).noquote()
- << "Changes to" << fileToRename.cmakeFile.path() << "could not be saved.";
- return false;
- }
+ editor->editorWidget()->autoIndent();
+ if (!Core::DocumentManager::saveDocument(editor->document())) {
+ qCCritical(cmakeBuildSystemLog).noquote()
+ << "Changes to" << fileToRename->cmakeFile.path() << "could not be saved.";
+ return false;
+ }
+
+ // Try the next occurrence. This can happen if set_source_file_properties is used
+ fileToRename = projectFileArgumentPosition(targetName, oldRelPathName);
+ } while (fileToRename);
return true;
}